@@ -10,20 +10,20 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'BINDIR': '/usr/pkg/bin',
  'BINLIBDEST': '/usr/pkg/lib/python2.7',
  'BLDLIBRARY': '-L. -lpython2.7',
- 'BLDSHARED': 'gcc -shared -L/usr/pkgsrc/lang/python27/work/Python-2.7.14 -pthread -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
+ 'BLDSHARED': 'gcc -shared -L/mnt/aarch64/pkgsrc/lang/python27/work.aarch64/Python-2.7.16 -pthread -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'CC': 'gcc',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-fno-strict-aliasing -O2 -fno-reorder-blocks -D_FORTIFY_SOURCE=2 -pthread -I/usr/include -I/usr/pkg/include -DNDEBUG -O2 -fno-reorder-blocks -D_FORTIFY_SOURCE=2 -pthread -I/usr/include -I/usr/pkg/include',
+ 'CFLAGS': '-fno-strict-aliasing -O2 -fomit-frame-pointer -D_FORTIFY_SOURCE=2 -pthread -I/usr/include -I/usr/pkg/include -DNDEBUG -O2 -fomit-frame-pointer -D_FORTIFY_SOURCE=2 -pthread -I/usr/include -I/usr/pkg/include',
  'CFLAGSFORSHARED': '-fPIC',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
- 'CONFIG_ARGS': "'--with-threads' '--enable-shared' 'OPT=-O2 -fno-reorder-blocks -D_FORTIFY_SOURCE=2 -pthread -I/usr/include -I/usr/pkg/include' '--with-system-ffi' '--with-dbmliborder=ndbm:bdb' '--prefix=/usr/pkg' '--build=m68k--netbsdelf' '--host=m68k--netbsdelf' '--mandir=/usr/pkg/man' 'build_alias=m68k--netbsdelf' 'host_alias=m68k--netbsdelf' 'CC=gcc' 'CFLAGS=-O2 -fno-reorder-blocks -D_FORTIFY_SOURCE=2 -pthread -I/usr/include -I/usr/pkg/include' 'LDFLAGS=-L/usr/pkgsrc/lang/python27/work/Python-2.7.14 -pthread -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib' 'LIBS=' 'CPPFLAGS=-I/usr/include -I/usr/pkg/include' 'PKG_CONFIG=' 'PKG_CONFIG_PATH=' 'PKG_CONFIG_LIBDIR=/usr/pkgsrc/lang/python27/work/.buildlink/lib/pkgconfig:/usr/pkgsrc/lang/python27/work/.buildlink/share/pkgconfig'",
+ 'CONFIG_ARGS': "'--enable-shared' '--with-dbmliborder=ndbm:bdb' '--with-system-ffi' '--with-threads' '--prefix=/usr/pkg' '--build=aarch64--netbsd' '--host=aarch64--netbsd' '--mandir=/usr/pkg/man' 'build_alias=aarch64--netbsd' 'host_alias=aarch64--netbsd' 'CC=gcc' 'CFLAGS=-O2 -fomit-frame-pointer -D_FORTIFY_SOURCE=2 -pthread -I/usr/include -I/usr/pkg/include' 'LDFLAGS=-L/mnt/aarch64/pkgsrc/lang/python27/work.aarch64/Python-2.7.16 -pthread -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib' 'LIBS=' 'CPPFLAGS=-I/usr/include -I/usr/pkg/include' 'PKG_CONFIG=' 'PKG_CONFIG_PATH=' 'PKG_CONFIG_LIBDIR=/mnt/aarch64/pkgsrc/lang/python27/work.aarch64/.buildlink/lib/pkgconfig:/mnt/aarch64/pkgsrc/lang/python27/work.aarch64/.buildlink/share/pkgconfig'",
  'CONFINCLUDEDIR': '/usr/pkg/include',
  'CONFINCLUDEPY': '/usr/pkg/include/python2.7',
  'COREPYTHONPATH': ':plat-netbsd8:lib-tk:lib-old',
- 'COVERAGE_INFO': '/usr/pkgsrc/lang/python27/work/Python-2.7.14/coverage.info',
- 'COVERAGE_REPORT': '/usr/pkgsrc/lang/python27/work/Python-2.7.14/lcov-report',
+ 'COVERAGE_INFO': '/mnt/aarch64/pkgsrc/lang/python27/work.aarch64/Python-2.7.16/coverage.info',
+ 'COVERAGE_REPORT': '/mnt/aarch64/pkgsrc/lang/python27/work.aarch64/Python-2.7.16/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov report"',
  'CPPFLAGS': '-I. -IInclude -I./Include -I/usr/include -I/usr/pkg/include',
  'CXX': 'c++',
@@ -39,8 +39,8 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'DLINCLDIR': '.',
  'DLLLIBRARY': '',
  'DOUBLE_IS_ARM_MIXED_ENDIAN_IEEE754': 0,
- 'DOUBLE_IS_BIG_ENDIAN_IEEE754': 1,
- 'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 0,
+ 'DOUBLE_IS_BIG_ENDIAN_IEEE754': 0,
+ 'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 1,
  'DYNLOADFILE': 'dynload_shlib.o',
  'ENABLE_IPV6': 1,
  'ENSUREPIP': 'no',
@@ -87,12 +87,21 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_CONFSTR': 1,
  'HAVE_CONIO_H': 0,
  'HAVE_COPYSIGN': 1,
+ 'HAVE_CRYPT_H': 0,
  'HAVE_CTERMID': 1,
  'HAVE_CTERMID_R': 0,
+ 'HAVE_CURSES_FILTER': 1,
  'HAVE_CURSES_H': 1,
+ 'HAVE_CURSES_HAS_KEY': 1,
+ 'HAVE_CURSES_IMMEDOK': 1,
+ 'HAVE_CURSES_IS_PAD': 1,
  'HAVE_CURSES_IS_TERM_RESIZED': 1,
  'HAVE_CURSES_RESIZETERM': 1,
  'HAVE_CURSES_RESIZE_TERM': 1,
+ 'HAVE_CURSES_SYNCOK': 1,
+ 'HAVE_CURSES_TYPEAHEAD': 1,
+ 'HAVE_CURSES_USE_ENV': 1,
+ 'HAVE_CURSES_WCHGAT': 1,
  'HAVE_DECL_ISFINITE': 1,
  'HAVE_DECL_ISINF': 1,
  'HAVE_DECL_ISNAN': 1,
@@ -176,9 +185,8 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_KILLPG': 1,
  'HAVE_KQUEUE': 1,
  'HAVE_LANGINFO_H': 1,
- 'HAVE_LARGEFILE_SUPPORT': 1,
+ 'HAVE_LARGEFILE_SUPPORT': 0,
  'HAVE_LCHFLAGS': 1,
- 'HAVE_LCHMOD': 1,
  'HAVE_LCHOWN': 1,
  'HAVE_LGAMMA': 1,
  'HAVE_LIBDL': 0,
@@ -306,6 +314,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_SYS_SOCKET_H': 1,
  'HAVE_SYS_STATVFS_H': 1,
  'HAVE_SYS_STAT_H': 1,
+ 'HAVE_SYS_SYSMACROS_H': 0,
  'HAVE_SYS_TERMIO_H': 0,
  'HAVE_SYS_TIMES_H': 1,
  'HAVE_SYS_TIME_H': 1,
@@ -347,7 +356,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_WORKING_TZSET': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HOST_GNU_TYPE': 'm68k--netbsdelf',
+ 'HOST_GNU_TYPE': 'aarch64--netbsd',
  'HURD_C_THREADS': 0,
  'INCLDIRSTOMAKE': '/usr/pkg/include /usr/pkg/include /usr/pkg/include/python2.7 /usr/pkg/include/python2.7',
  'INCLUDEDIR': '/usr/pkg/include',
@@ -359,11 +368,11 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'INSTALL_SHARED': '/usr/bin/install -c -o root -g wheel -m 555',
  'INSTSONAME': 'libpython2.7.so.1.0',
  'LDCXXSHARED': 'c++ -shared',
- 'LDFLAGS': '-L/usr/pkgsrc/lang/python27/work/Python-2.7.14 -pthread -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
+ 'LDFLAGS': '-L/mnt/aarch64/pkgsrc/lang/python27/work.aarch64/Python-2.7.16 -pthread -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
  'LDLAST': '',
  'LDLIBRARY': 'libpython2.7.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'gcc -shared -L/usr/pkgsrc/lang/python27/work/Python-2.7.14 -pthread -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
+ 'LDSHARED': 'gcc -shared -L/mnt/aarch64/pkgsrc/lang/python27/work.aarch64/Python-2.7.16 -pthread -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
  'LIBC': '',
  'LIBDEST': '/usr/pkg/lib/python2.7',
  'LIBDIR': '/usr/pkg/lib',
@@ -406,7 +415,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'MVWDELCH_IS_EXPRESSION': 1,
  'OBJECT_OBJS': '\\',
  'OLDPATH': ':lib-old',
- 'OPT': '-DNDEBUG -O2 -fno-reorder-blocks -D_FORTIFY_SOURCE=2 -pthread -I/usr/include -I/usr/pkg/include',
+ 'OPT': '-DNDEBUG -O2 -fomit-frame-pointer -D_FORTIFY_SOURCE=2 -pthread -I/usr/include -I/usr/pkg/include',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -440,10 +449,10 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': ':plat-netbsd8:lib-tk:lib-old',
  'PYTHON_FOR_BUILD': './python -E',
- 'PYTHON_FOR_REGEN': 'python3',
+ 'PYTHON_FOR_REGEN': 'python2.7',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_CFLAGS': '-fno-strict-aliasing -O2 -fno-reorder-blocks -D_FORTIFY_SOURCE=2 -pthread -I/usr/include -I/usr/pkg/include -DNDEBUG -O2 -fno-reorder-blocks -D_FORTIFY_SOURCE=2 -pthread -I/usr/include -I/usr/pkg/include -I. -IInclude -I./Include -I/usr/include -I/usr/pkg/include -fPIC -DPy_BUILD_CORE',
+ 'PY_CFLAGS': '-fno-strict-aliasing -O2 -fomit-frame-pointer -D_FORTIFY_SOURCE=2 -pthread -I/usr/include -I/usr/pkg/include -DNDEBUG -O2 -fomit-frame-pointer -D_FORTIFY_SOURCE=2 -pthread -I/usr/include -I/usr/pkg/include -I. -IInclude -I./Include -I/usr/include -I/usr/pkg/include -fPIC -DPy_BUILD_CORE',
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_UNICODE_TYPE': 'unsigned short',
@@ -455,7 +464,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'RANLIB': 'ranlib',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/pkgsrc/lang/python27/work/Python-2.7.14',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/mnt/aarch64/pkgsrc/lang/python27/work.aarch64/Python-2.7.16',
  'SCRIPTDIR': '/usr/pkg/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SGI_ABI': '',
@@ -469,17 +478,17 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'SIZEOF_FLOAT': 4,
  'SIZEOF_FPOS_T': 264,
  'SIZEOF_INT': 4,
- 'SIZEOF_LONG': 4,
- 'SIZEOF_LONG_DOUBLE': 12,
+ 'SIZEOF_LONG': 8,
+ 'SIZEOF_LONG_DOUBLE': 16,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
- 'SIZEOF_PTHREAD_T': 4,
+ 'SIZEOF_PTHREAD_T': 8,
  'SIZEOF_SHORT': 2,
- 'SIZEOF_SIZE_T': 4,
+ 'SIZEOF_SIZE_T': 8,
  'SIZEOF_TIME_T': 8,
- 'SIZEOF_UINTPTR_T': 4,
- 'SIZEOF_VOID_P': 4,
+ 'SIZEOF_UINTPTR_T': 8,
+ 'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
  'SO': '.so',
@@ -498,7 +507,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'TESTOPTS': '-l',
  'TESTPATH': '',
  'TESTPROG': './Lib/test/regrtest.py',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/pkgsrc/lang/python27/work/Python-2.7.14 ./python -Wd -3 -E -tt',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/mnt/aarch64/pkgsrc/lang/python27/work.aarch64/Python-2.7.16 ./python -Wd -3 -E -tt',
  'TESTPYTHONOPTS': '',
  'THREADOBJ': 'Python/thread.o',
  'TIME_WITH_SYS_TIME': 1,
@@ -521,13 +530,13 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'WITH_THREAD': 1,
  'WITH_TSC': 0,
  'WITH_VALGRIND': 0,
- 'X87_DOUBLE_ROUNDING': 1,
+ 'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/usr/pkgsrc/lang/python27/work/Python-2.7.14',
- 'abs_srcdir': '/usr/pkgsrc/lang/python27/work/Python-2.7.14',
- 'build': 'm68k--netbsdelf',
+ 'abs_builddir': '/mnt/aarch64/pkgsrc/lang/python27/work.aarch64/Python-2.7.16',
+ 'abs_srcdir': '/mnt/aarch64/pkgsrc/lang/python27/work.aarch64/Python-2.7.16',
+ 'build': 'aarch64--netbsd',
  'datarootdir': '/usr/pkg/share',
  'exec_prefix': '/usr/pkg',
- 'host': 'm68k--netbsdelf',
+ 'host': 'aarch64--netbsd',
  'prefix': '/usr/pkg',
  'srcdir': '.'}
