@@ -3,14 +3,9 @@ dyld emulation
 """
 
 import os
-from ctypes.macholib.framework import framework_info
-from ctypes.macholib.dylib import dylib_info
+from framework import framework_info
+from dylib import dylib_info
 from itertools import *
-try:
-    from _ctypes import _dyld_shared_cache_contains_path
-except ImportError:
-    def _dyld_shared_cache_contains_path(*args):
-        raise NotImplementedError
 
 __all__ = [
     'dyld_find', 'framework_find',
@@ -28,11 +23,17 @@ DEFAULT_FRAMEWORK_FALLBACK = [
 
 DEFAULT_LIBRARY_FALLBACK = [
     os.path.expanduser("~/lib"),
-    "/usr/local/lib",
+    "/usr/pkg/lib",
     "/lib",
     "/usr/lib",
 ]
 
+def ensure_utf8(s):
+    """Not all of PyObjC and Python understand unicode paths very well yet"""
+    if isinstance(s, unicode):
+        return s.encode('utf8')
+    return s
+
 def dyld_env(env, var):
     if env is None:
         env = os.environ
@@ -122,20 +123,15 @@ def dyld_find(name, executable_path=None, env=None):
     """
     Find a library or framework using dyld semantics
     """
+    name = ensure_utf8(name)
+    executable_path = ensure_utf8(executable_path)
     for path in dyld_image_suffix_search(chain(
                 dyld_override_search(name, env),
                 dyld_executable_path_search(name, executable_path),
                 dyld_default_search(name, env),
             ), env):
-
         if os.path.isfile(path):
             return path
-        try:
-            if _dyld_shared_cache_contains_path(path):
-                return path
-        except NotImplementedError:
-            pass
-
     raise ValueError("dylib %s could not be found" % (name,))
 
 def framework_find(fn, executable_path=None, env=None):
@@ -147,11 +143,10 @@ def framework_find(fn, executable_path=None, env=None):
         Python.framework
         Python.framework/Versions/Current
     """
-    error = None
     try:
         return dyld_find(fn, executable_path=executable_path, env=env)
-    except ValueError as e:
-        error = e
+    except ValueError, e:
+        pass
     fmwk_index = fn.rfind('.framework')
     if fmwk_index == -1:
         fmwk_index = len(fn)
@@ -160,9 +155,7 @@ def framework_find(fn, executable_path=None, env=None):
     try:
         return dyld_find(fn, executable_path=executable_path, env=env)
     except ValueError:
-        raise error
-    finally:
-        error = None
+        raise e
 
 def test_dyld_find():
     env = {}
